@@ -1,7 +1,7 @@
 package bignum;
 require 5.005;
 
-$VERSION = '0.08';
+$VERSION = '0.09';
 use Exporter;
 @ISA =       qw( Exporter );
 @EXPORT_OK = qw( ); 
@@ -13,7 +13,7 @@ use strict;
 # These are all alike, and thus faked by AUTOLOAD
 
 my @faked = qw/round_mode accuracy precision div_scale/;
-use vars qw/$AUTOLOAD $_lite/;		# _lite for testsuite
+use vars qw/$VERSION $AUTOLOAD $_lite/;		# _lite for testsuite
 
 sub AUTOLOAD
   {
@@ -160,6 +160,7 @@ sub import
   bignum->precision($p) if defined $p;
   if ($ver)
     {
+    print "bignum\t\t\t v$VERSION\n";
     print "Math::BigInt::Lite\t v$Math::BigInt::Lite::VERSION\n" if $_lite;
     print "Math::BigInt\t\t v$Math::BigInt::VERSION";
     my $config = Math::BigInt->config();
